import aiounittest
import asyncio
import time
import sys
from unittest import expectedFailure


async def async_add(x, y, delay=0.1):
    await asyncio.sleep(delay)
    return x + y


def sync_add(x, y, delay=0.1):
    time.sleep(delay)
    return x + y

async def async_one():
    await async_nested_exc()

async def async_nested_exc():
    await asyncio.sleep(0.1)
    raise Exception('Test')


class TestAsyncCase(aiounittest.AsyncTestCase):

    def test_sync_add(self):
        ret = sync_add(1, 5)
        self.assertEqual(ret, 6)

    def test_sync_async_add(self):
        loop = asyncio.get_event_loop()
        ret = loop.run_until_complete(async_add(1,5))
        loop.close()
        self.assertEqual(ret, 6)

        # Set a new event loop, since we closed the old one
        asyncio.set_event_loop(asyncio.new_event_loop())

    async def test_await_async_add(self):
        ret = await async_add(1, 5)
        self.assertEqual(ret, 6)

    if sys.version_info < (3, 11):
        @asyncio.coroutine
        def test_yield_async_add(self):
            ret = yield from async_add(1, 5)
            self.assertEqual(ret, 6)

    async def test_await_async_fail(self):
        with self.assertRaises(Exception) as e:
            await async_one()

    @expectedFailure
    async def test_failure_await_async_add(self):
        ret = await async_add(1, 5)
        self.assertEqual(ret, -1)

    if sys.version_info < (3, 11):
        @expectedFailure
        @asyncio.coroutine
        def test_yield_async_add(self):
            ret = yield from async_add(1, 5)
            self.assertEqual(ret, -1)



import asyncio
import unittest
from aiounittest import async_test


async def add(x, y):
    await asyncio.sleep(0.1)
    return x + y

class MyAsyncTestDecorator(unittest.TestCase):

    @async_test
    async def test_async_add(self):
        ret = await add(5, 6)
        self.assertEqual(ret, 11)

    @unittest.expectedFailure
    @async_test
    async def test_async_add(self):
        ret = await add(5, 6)
        self.assertEqual(ret, 44)

    def test_async_test_with_custom_loop(self):

        async def some_func():
            ret = await add(5, 6)
            assert ret == 11
            return 'OK'

        loop = asyncio.get_event_loop()
        wrapped = async_test(some_func, loop=loop)

        res = wrapped()

        self.assertEqual(res, 'OK')

        # decorator should not change the state (eg close) of the loop if it's custom
        self.assertFalse(loop.is_closed())



from aiounittest import futurized, AsyncTestCase
from unittest.mock import Mock, patch

import dummy_math

class MyAddTest(AsyncTestCase):

    async def test_add(self):
        mock_sleep = Mock(return_value=futurized('whatever'))
        patch('dummy_math.sleep', mock_sleep).start()
        ret = await dummy_math.add(5, 6)
        self.assertEqual(ret, 11)
        mock_sleep.assert_called_once_with(666)

    async def test_fail(self):
        mock_sleep = Mock(return_value=futurized(Exception('whatever')))
        patch('dummy_math.sleep', mock_sleep).start()
        with self.assertRaises(Exception) as e:
            await dummy_math.add(5, 6)
        mock_sleep.assert_called_once_with(666)



import sys
from unittest.main import main


def test_specific_test():
    sys.argv = ['TEST']
    sys.argv.append('test_asynctestcase.TestAsyncCase.test_await_async_add')
    a = main(module=None, exit=False)



import aiounittest
import asyncio
import time
import sys
from unittest import expectedFailure


async def async_add(x, y, delay=0.1):
    await asyncio.sleep(delay)
    return x + y


def sync_add(x, y, delay=0.1):
    time.sleep(delay)
    return x + y


async def async_one():
    await async_nested_exc()


async def async_nested_exc():
    await asyncio.sleep(0.1)
    raise Exception('Test')


class TestAsyncCaseWithCustomLoop(aiounittest.AsyncTestCase):

    def get_event_loop(self):
        self.my_loop = asyncio.get_event_loop()
        return self.my_loop

    async def test_await_async_add(self):
        ret = await async_add(1, 5)
        self.assertEqual(ret, 6)
        self.assertFalse(self.my_loop.is_closed())

    if sys.version_info < (3, 11):
        @asyncio.coroutine
        def test_yield_async_add(self):
            ret = yield from async_add(1, 5)
            self.assertEqual(ret, 6)
            self.assertFalse(self.my_loop.is_closed())



#!/usr/bin/env python
# -*- coding:utf-8 -*-
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name='aiounittest',
    packages=['aiounittest'],
    version='1.5.0',
    author='Krzysztof Warunek',
    author_email='krzysztof@warunek.net',
    description='Test asyncio code more easily.',
    include_package_data=True,
    keywords='asyncio, async, unittest, coroutine',
    url='https://github.com/kwarunek/aiounittest',
    long_description=open('README.rst').read(),
    package_data={'aiounittest': ['py.typed']},
    install_requires=open('requirements.txt').read().splitlines(),
    license="MIT",
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ]
)



from aiounittest import AsyncTestCase
from aiounittest.mock import AsyncMockIterator
from unittest.mock import Mock


async def fetch_some_text(source):
    res = ''
    async for txt in source.paginate():
        res += txt
    return res


class MyAsyncMockIteratorTest(AsyncTestCase):

    async def test_add(self):
        source = Mock()
        mock_iter = AsyncMockIterator([
            'asdf', 'qwer', 'zxcv'
        ])
        source.paginate.return_value = mock_iter

        res = await fetch_some_text(source)
        self.assertEqual(res, 'asdfqwerzxcv')
        mock_iter.assertFullyConsumed()
        mock_iter.assertIterCount(3)
